@@ -1,15 +1,13 @@
-# $Id: LoggingTab.pm,v 1.8 2004/04/11 23:36:20 joern Exp $
+# $Id: LoggingTab.pm,v 1.1 2001/12/15 00:21:22 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Project;
-use Locale::TextDomain qw (video.dvdrip);
 
 use Video::DVDRip::GUI::Logger;
 
@@ -27,7 +25,7 @@ sub create_logging_tab {
 	$vbox->set_border_width(5);
 	$vbox->show;
 	
-	my $frame = Gtk::Frame->new (__"Log messages");
+	my $frame = Gtk::Frame->new ("Log Messages");
 	$frame->show;
 
 	my $hbox = Gtk::HBox->new;
@@ -43,6 +41,7 @@ sub create_logging_tab {
 
 	my $text = new Gtk::Text( undef, undef );
 	$text->show;
+	$text->set_usize (undef, $self->config('main_window_height') - 200);
 	$text->set_editable( 0 );
 	$text->set_word_wrap ( 1 );
 	$text_table->attach( $text, 0, 1, 0, 1,
@@ -56,18 +55,7 @@ sub create_logging_tab {
 	$vscrollbar->show();
 
 	$frame->add ($hbox);
-	$vbox->pack_start ( $frame, 1, 1, 0);
-
-	my $button = Gtk::Button->new (__"Nuke log file");
-	$button->show;
-	$hbox = Gtk::HBox->new;
-	$hbox->show;
-	$hbox->pack_start ( $button, 0, 1, 0);
-	$vbox->pack_start ( $hbox,  0, 1, 0);
-
-	$button->signal_connect ("clicked", sub {
-		$self->nuke_log;
-	});
+	$vbox->pack_start ( $frame, 0, 1, 0);
 
 	my $logger = Video::DVDRip::GUI::Logger->new (
 		text_widget => $text,
@@ -79,15 +67,4 @@ sub create_logging_tab {
 	return $vbox;
 }
 
-sub nuke_log {
-	my $self = shift;
-
-	my $title = $self->selected_title;
-	return 1 if not $title;
-	
-	$self->logger->nuke;
-	
-	1;
-}
-
 1;
